Length class

Represents the unit category for length measurements (e.g., inch, centimeter).

Constructors

Length()
Provides access to the singleton instance of Length.
factory

Properties

centimeter → ScaleUnit
Returns the ScaleUnit for centimeters.
no setter
Returns the ScaleUnit for feet.
no setter
hashCode → int
The hash code for this object.
no setterinherited
inch → ScaleUnit
Returns the ScaleUnit for inches.
no setter
kilometer → ScaleUnit
Returns the ScaleUnit for kilometers.
no setter
meter → ScaleUnit
Returns the ScaleUnit for meters.
no setter
micrometer → ScaleUnit
Returns the ScaleUnit for micrometers.
no setter
mile → ScaleUnit
Returns the ScaleUnit for miles.
no setter
millimeter → ScaleUnit
Returns the ScaleUnit for millimeters.
no setter
nanometer → ScaleUnit
Returns the ScaleUnit for nanometers.
no setter
nauticalMile → ScaleUnit
Returns the ScaleUnit for nautical miles.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
yard → ScaleUnit
Returns the ScaleUnit for yards.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

lengths ↔ List<ScaleUnit>
A list of ScaleUnit objects representing different length units.
getter/setter pair