ScaleUnit class

Represents a unit of measurement with a unique ID, name, symbol, unit group, and a list of unit intervals defining the measurement range.

Constructors

ScaleUnit({required String name, required String symbol, required int subDivisionCount, required List<ScaleIntervals> scaleIntervals})
Creates an instance of ScaleUnit with the specified id, name, symbol, subDivisionCount, and scaleIntervals.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
The name of the unit (e.g., 'inch', 'centimeter').
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleIntervals ↔ List<ScaleIntervals>
A list of unit scale intervals representing ranges and scales for the unit.
getter/setter pair
subDivisionCount ↔ int
The unit group category to which the unit belongs (e.g., 10 for centimeter, 12 for inches).
getter/setter pair
symbol ↔ String
The symbol representing the unit (e.g., 'in', 'cm').
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited