Weight class

Represents the unit category for weight measurements (e.g., kilogram, pounds).

Constructors

Weight()
Provides access to the singleton instance of Length.
factory

Properties

gram → ScaleUnit
Returns the ScaleUnit for grams.
no setter
hashCode → int
The hash code for this object.
no setterinherited
imperialTon → ScaleUnit
Returns the ScaleUnit for imperial tons.
no setter
kilogram → ScaleUnit
Returns the ScaleUnit for kilograms.
no setter
microgram → ScaleUnit
Returns the ScaleUnit for micrograms.
no setter
milligram → ScaleUnit
Returns the ScaleUnit for milligrams.
no setter
ounce → ScaleUnit
Returns the ScaleUnit for ounces.
no setter
pound → ScaleUnit
Returns the ScaleUnit for pounds.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stone → ScaleUnit
Returns the ScaleUnit for stones.
no setter
tonne → ScaleUnit
Returns the ScaleUnit for tonnes.
no setter
usTon → ScaleUnit
Returns the ScaleUnit for US tons.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

weights ↔ List<ScaleUnit>
A list of ScaleUnit objects representing different weight units.
getter/setter pair